@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 - 2020 GraphicsMagick Group
+  Copyright (C) 2003 - 2024 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
 
@@ -34,12 +34,12 @@ extern "C" {
   identifying the release.
 */
 #define MagickPackageName "GraphicsMagick"
-#define MagickCopyright  "Copyright (C) 2002-2020 GraphicsMagick Group.\nAdditional copyrights and licenses apply to this software.\nSee http://www.GraphicsMagick.org/www/Copyright.html for details."
-#define MagickLibVersion  0x252200
-#define MagickLibVersionText  "1.3.36"
-#define MagickLibVersionNumber 25,22,0
-#define MagickChangeDate   "20201226"
-#define MagickReleaseDate  "20201226"
+#define MagickCopyright  "Copyright (C) 2002-2024 GraphicsMagick Group.\nAdditional copyrights and licenses apply to this software.\nSee http://www.GraphicsMagick.org/www/Copyright.html for details."
+#define MagickLibVersion  0x282500
+#define MagickLibVersionText  "1.3.43"
+#define MagickLibVersionNumber 28,25,0
+#define MagickChangeDate   "20240323"
+#define MagickReleaseDate  "2024-03-23"
 
 /*
   The MagickLibInterfaceNewest and MagickLibInterfaceOldest defines
@@ -54,7 +54,7 @@ extern "C" {
   MagickLibVersionNumber, but these are broken out and simplified so
   that they can be easily used in C pre-processor logic.
 */
-#define MagickLibInterfaceNewest 25
+#define MagickLibInterfaceNewest 28
 #define MagickLibInterfaceOldest 3
 
 #if (QuantumDepth == 8)
